Magic-number elimination.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index b2db8a6a54097913ad2068c701533b34b8f66008..c31ee6a88dc2ec7bcc0d0c856869b0f4d585c5cf 100644 (file)
--- a/score.c
+++ b/score.c
@@ -1,7 +1,6 @@
 #include <stdlib.h>
 #include "advent.h"
-#include "database.h"
-#include "newdb.h"
+#include "dungeon.h"
 
 /*
  * scoring and wrap-up
@@ -37,33 +36,39 @@ long score(enum termination mode)
     /*  First tally up the treasures.  Must be in building and not broken.
      *  Give the poor guy 2 points just for finding each treasure. */
     mxscor = 0;
-    for (long i = MINTRS; i <= MAXTRS; i++) {
-        if (object_descriptions[i].inventory != 0) {
+    for (int i = 1; i <= NOBJECTS; i++) {
+        if (!objects[i].is_treasure)
+            continue;
+        if (objects[i].inventory != 0) {
             long k = 12;
-            if (i == CHEST)k = 14;
-            if (i > CHEST)k = 16;
-            if (game.prop[i] >= 0)
+            if (i == CHEST)
+                k = 14;
+            if (i > CHEST)
+                k = 16;
+            if (game.prop[i] > STATE_NOTFOUND)
                 score += 2;
-            if (game.place[i] == LOC_BUILDING && game.prop[i] == 0)
+            if (game.place[i] == LOC_BUILDING && game.prop[i] == STATE_FOUND)
                 score += k - 2;
             mxscor += k;
         }
     }
 
/*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (maximum_deaths - game.numdie) * 10;
-    mxscor += maximum_deaths * 10;
+    score += (NDEATHS - game.numdie) * 10;
+    mxscor += NDEATHS * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
-    if (game.dflag != 0)score += 25;
+    if (game.dflag != 0)
+        score += 25;
     mxscor += 25;
-    if (game.closng)score += 25;
+    if (game.closng)
+        score += 25;
     mxscor += 25;
     if (game.closed) {
         if (game.bonus == 0)
@@ -87,9 +92,9 @@ long score(enum termination mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (long i = 1; i <= HINT_COUNT; i++) {
+    for (long i = 0; i < NHINTS; i++) {
         if (game.hinted[i])
-            score = score - hints[i-1].penalty;
+            score = score - hints[i].penalty;
     }
     if (game.novice)
         score -= 5;
@@ -115,17 +120,17 @@ void terminate(enum termination mode)
     if (points + game.saved + 1 >= mxscor && game.saved != 0)
         rspeak(WITHOUT_SUSPENDS);
     rspeak(TOTAL_SCORE, points, mxscor, game.turns, game.turns);
-    for (long i = 1; i <= (long)CLSSES; i++) {
+    for (long i = 1; i <= (long)NCLASSES; i++) {
         if (classes[i].threshold >= points) {
             speak(classes[i].message);
             i = classes[i].threshold + 1 - points;
             rspeak(NEXT_HIGHER, i, i);
-            exit(0);
+            exit(EXIT_SUCCESS);
         }
     }
     rspeak(OFF_SCALE);
     rspeak(NO_HIGHER);
-    exit(0);
+    exit(EXIT_SUCCESS);
 }
 
 /* end */
@@ -37,33 +36,39 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  maximum_deaths and
+    /*  Now look at how he finished and how far he got.  NDEATHS and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still